"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImportConnectionsModal = void 0;
const react_1 = __importStar(require("react"));
const compass_components_1 = require("@mongodb-js/compass-components");
const file_input_1 = require("./file-input");
const passphrase_1 = require("./passphrase");
const common_1 = require("../hooks/common");
const use_import_connections_1 = require("../hooks/use-import-connections");
const TOAST_TIMEOUT_MS = 5000;
const tableStyles = (0, compass_components_1.css)({
    maxHeight: '24vh',
    overflow: 'auto',
});
const existingFavoriteBadgeStyles = (0, compass_components_1.css)({
    marginLeft: compass_components_1.spacing[200],
});
const SelectListLabel = {
    displayLabelKey: 'displayName',
    ariaLabelKey: 'name',
    name: 'Connection Name',
};
function ImportConnectionsModal({ open, setOpen, trackingProps, }) {
    const finish = (0, react_1.useCallback)((result) => {
        setOpen(false);
        if (result === 'succeeded') {
            (0, compass_components_1.openToast)('compass-connection-import-export--import-succeeded', {
                title: 'Import successful',
                description: 'New connections have been added',
                variant: 'success',
                timeout: TOAST_TIMEOUT_MS,
            });
        }
    }, [setOpen]);
    const openModalThroughIpc = (0, react_1.useCallback)(() => {
        setOpen(true, { context: 'menuBar' });
    }, [setOpen]);
    (0, common_1.useOpenModalThroughIpc)(open, openModalThroughIpc, 'compass:open-import-connections');
    const { onSubmit, onCancel, onChangeFilename, onChangePassphrase, onChangeConnectionList, state: { inProgress, error, passphraseRequired, connectionList, filename, passphrase, }, } = (0, use_import_connections_1.useImportConnections)({
        finish,
        open,
        trackingProps,
    });
    const [displayConnectionList, hasSelectedDuplicates] = (0, react_1.useMemo)(() => {
        return [
            connectionList.map((conn) => ({
                ...conn,
                displayName: (react_1.default.createElement(react_1.default.Fragment, null,
                    conn.name,
                    conn.isExistingConnection && (react_1.default.createElement(compass_components_1.Badge, { className: existingFavoriteBadgeStyles, variant: conn.selected ? 'yellow' : 'lightgray', "data-testid": `existing-favorite-badge-${conn.id}` }, "Existing Connection")))),
            })),
            connectionList.some((conn) => conn.isExistingConnection && conn.selected),
        ];
    }, [connectionList]);
    return (react_1.default.createElement(compass_components_1.FormModal, { open: open, onCancel: onCancel, onSubmit: onSubmit, title: "Import saved connections", submitButtonText: "Import", submitDisabled: inProgress || !!error || !filename, "data-testid": "connection-import-modal" },
        react_1.default.createElement(compass_components_1.FormFieldContainer, null,
            react_1.default.createElement(file_input_1.FileInput, { label: "Source File", mode: "open", disabled: inProgress, onChange: onChangeFilename, value: filename })),
        react_1.default.createElement(compass_components_1.FormFieldContainer, null,
            react_1.default.createElement(passphrase_1.Passphrase, { label: "Decryption Password", description: "Passphrase to decrypt secrets if one has been specified while exporting", required: passphraseRequired, accepted: connectionList.length > 0, disabled: inProgress, onChange: onChangePassphrase, value: passphrase })),
        connectionList.length > 0 && (react_1.default.createElement(compass_components_1.SelectList, { className: tableStyles, items: displayConnectionList, label: SelectListLabel, disabled: inProgress, onChange: onChangeConnectionList })),
        (error && !passphraseRequired && (react_1.default.createElement(compass_components_1.Banner, { variant: "danger" },
            "Error: ",
            error))) ||
            (hasSelectedDuplicates && (react_1.default.createElement(compass_components_1.Banner, { variant: "warning" }, "Some connections are already saved and will be overwritten by importing them")))));
}
exports.ImportConnectionsModal = ImportConnectionsModal;
//# sourceMappingURL=import-modal.js.map